MockSource class

Implemented types

Constructors

MockSource(Migration first, {Migration? next})

Properties

first ↔ Migration
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
next ↔ Migration?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getInitial() → Future<Migration>
Returns the initial migration to be applied to a fresh database.
override
getNext(String currentVersion) → Future<Migration?>
Returns the next migration after the version. Returns null if the version is the last.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited